@@ -10,7 +10,7 @@
 #'   \item{Rattus_norvegicus_mito_ensembl}{Ensembl IDs for rat mitochondrial genes}
 #'   \item{Drosophila_melanogaster_mito_ensembl}{Ensembl IDs for fly mitochondrial genes}
 #'   \item{Macaca_mulatta_mito_ensembl}{Ensembl IDs for macaque mitochondrial genes}
-#'   \item{Gallus_gallus_ribo_ensembl}{Ensembl IDs for chicken mitochondrial genes}
+#'   \item{Gallus_gallus_mito_ensembl}{Ensembl IDs for chicken mitochondrial genes}
 #' }
 #' @concept data
 #' @source See data-raw directory for scripts used to create gene list.
@@ -170,3 +170,99 @@
 #' homologs according to HGNC.  See data-raw directory for scripts used to create gene list.
 #'
 "ensembl_ieg_list"
+
+
+#' MALAT1 gene lists
+#'
+#' Ensembl IDs for MALAT1 (Ensembl version 112; 4/29/2024)
+#'
+#' @format A list of seven vectors
+#' \describe{
+#'   \item{Mus_musculus_MALAT1_ensembl}{Ensembl ID for mouse Malat1}
+#'   \item{Homo_sapiens_MALAT1_ensembl}{Ensembl ID for human MALAT1}
+#'
+#' }
+#' @concept data
+#'
+#' @source See data-raw directory for scripts used to create gene list.
+#'
+"ensembl_malat1_list"
+
+
+#' exAM gene lists
+#'
+#' Gene symbols for exAM genes
+#'
+#' @format A list of three vectors
+#' \describe{
+#'   \item{Mus_musculus_exAM_union}{Gene symbols for exAM genes from source publication (see below)}
+#'   \item{Homo_sapiens_exAM_union}{Human gene symbols for homologous genes from mouse gene list}
+#'   \item{Homo_sapiens_exAM_micro}{Human gene symbols for human microglia list}
+#'
+#' }
+#' @concept data
+#'
+#' @source Gene list is from: SI Table 22 Marsh et al., 2022 (Nature Neuroscience) from \doi{10.1038/s41593-022-01022-8}.
+#' See data-raw directory for scripts used to create gene list.
+#'
+"exAM_gene_list"
+
+
+#' Immediate Early Gene (IEG) gene lists
+#'
+#' Ensembl IDs for immediate early genes (Ensembl version 112; 4/29/2024)
+#'
+#' @format A list of three vectors
+#' \describe{
+#'   \item{Mus_musculus_exAM_union_ensembl}{Ensembl ID for exAM genes from source publication (see below)}
+#'   \item{Homo_sapiens_exAM_union_ensembl}{Human Ensembl ID for exAM genes for homologous genes from mouse gene list}
+#'   \item{Homo_sapiens_exAM_micro_ensembl}{Human Ensembl ID for exAM genes for human microglia list}
+#'
+#' }
+#' @concept data
+#'
+#' @source Gene list is from: SI Table 22 Marsh et al., 2022 (Nature Neuroscience) from \doi{10.1038/s41593-022-01022-8}.
+#' See data-raw directory for scripts used to create gene list.
+#'
+"ensembl_exAM_list"
+
+
+#' Ensembl lncRNA IDs
+#'
+#' A list of ensembl ids for lncRNA genes (Ensembl version 113; 04/08/2025)
+#'
+#' @format A list of seven vectors
+#' \describe{
+#'   \item{Mus_musculus_lncRNA_ensembl}{Ensembl IDs for mouse lncRNA genes}
+#'   \item{Homo_sapiens_lncRNA_ensembl}{Ensembl IDs for human lncRNA genes}
+#'   \item{Callithrix_jacchus_lncRNA_ensembl}{Ensembl IDs for marmoset lncRNA genes}
+#'   \item{Danio_rerio_lncRNA_ensembl}{Ensembl IDs for zebrafish lncRNA genes}
+#'   \item{Rattus_norvegicus_lncRNA_ensembl}{Ensembl IDs for rat lncRNA genes}
+#'   \item{Macaca_mulatta_lncRNA_ensembl}{Ensembl IDs for macaque lncRNA genes}
+#'   \item{Gallus_gallus_lncRNA_ensembl}{Ensembl IDs for chicken lncRNA genes}
+#' }
+#' @concept data
+#' @source See data-raw directory for scripts used to create gene list.
+#'
+#'
+"ensembl_lncRNA_id"
+
+
+#' lncRNA gene list
+#'
+#' A list of gene symbol ids for lncRNA genes (Ensembl version 113; 04/08/2025)
+#'
+#' @format A list of six vectors
+#' \describe{
+#'   \item{Mus_musculus_lncRNA}{Ensembl IDs for mouse lncRNA genes}
+#'   \item{Homo_sapiens_lncRNA}{Ensembl IDs for human lncRNA genes}
+#'   \item{Danio_rerio_lncRNA}{Ensembl IDs for zebrafish lncRNA genes}
+#'   \item{Rattus_norvegicus_lncRNA}{Ensembl IDs for rat lncRNA genes}
+#'   \item{Macaca_mulatta_lncRNA}{Ensembl IDs for macaque lncRNA genes}
+#'   \item{Gallus_gallus_lncRNA}{Ensembl IDs for chicken lncRNA genes}
+#' }
+#' @concept data
+#' @source See data-raw directory for scripts used to create gene list.
+#'
+#'
+"lncRNA_gene_list"
