@@ -54,6 +54,11 @@ Iterate_PC_Loading_Plots <- function(
     }
   }
 
+  # check file extension
+  if (isFALSE(x = check_extension(file_name = file_name, extension = ".pdf"))) {
+    file_name <- paste0(file_name, ".pdf")
+  }
+
   # Set dims to plot if not specified
   num_pc_present <- length(seurat_object@reductions$pca@stdev)
   if (is.null(x = dims_plot)) {
@@ -77,9 +82,11 @@ Iterate_PC_Loading_Plots <- function(
   all_plots <- pblapply(dims_list, function(x) {
     PC_Plotting(seurat_object = seurat_object, dim_number = x)
   })
+
+
   # Save plots
   cli_inform(message = "Saving plots to file")
-  pdf(file = paste(file_path, name_prefix, file_name, ".pdf", sep=""), height = 11, width = 8.5)
+  pdf(file = paste(file_path, name_prefix, file_name, sep=""), height = 11, width = 8.5)
   pb <- txtProgressBar(min = 0, max = length(all_plots), style = 3, file = stderr())
   for (i in 1:length(all_plots)) {
     print(all_plots[[i]])
@@ -387,7 +394,7 @@ Iterate_DimPlot_bySample <- function(
 #' @examples
 #' \dontrun{
 #' Iterate_Cluster_Highlight_Plot(seurat_object = object, highlight_color = "navy",
-#' background_color = "lightgray", file_path = "path/", file_name = "name", file_type = "pdf",
+#' background_color = "lightgray", file_path = "path/", file_name = "name", file_type = ".pdf",
 #' single_pdf = TRUE)
 #' }
 #'
@@ -600,7 +607,7 @@ Iterate_Cluster_Highlight_Plot <- function(
 #' \dontrun{
 #' Iterate_Meta_Highlight_Plot(seurat_object = object, meta_data_column = "sample_id",
 #' highlight_color = "navy", background_color = "lightgray", file_path = "path/",
-#' file_name = "name", file_type = "pdf", single_pdf = TRUE)
+#' file_name = "name", file_type = ".pdf", single_pdf = TRUE)
 #' }
 #'
 
